#############################
Party Address Location Module
#############################

The *Party Address Location Module* adds a latitude and longitude to
addresses.

.. toctree::
   :maxdepth: 2

   installation
   setup
   configuration
   design
   reference
   support
   license
